==> saga_2.2.3+dfsg.orig.tar.gz: saga-2.2.3/src/modules/shapes/shapes_polygons/polygon_shared_edges.h <==
/**********************************************************
 * Version $Id: polygon_shared_edges.h 911 2011-02-14 16:38:15Z reklov_w $
 *********************************************************/

///////////////////////////////////////////////////////////
//                                                       //
//                         SAGA                          //
//                                                       //
//      System for Automated Geoscientific Analyses      //
//                                                       //
//                    Module Library:                    //
//                    shapes_polygons                    //
//                                                       //
//-------------------------------------------------------//
//                                                       //
//                 polygon_shared_edges.h                //
//                                                       //
//                 Copyright (C) 2014 by                 //
//                      Olaf Conrad                      //
//                                                       //
//-------------------------------------------------------//
//                                                       //
// This file is part of 'SAGA - System for Automated     //
// Geoscientific Analyses'. SAGA is free software; you   //
// can redistribute it and/or modify it under the terms  //
// of the GNU General Public License as published by the //
// Free Software Foundation; version 2 of the License.   //
//                                                       //
// SAGA is distributed in the hope that it will be       //
// useful, but WITHOUT ANY WARRANTY; without even the    //
// implied warranty of MERCHANTABILITY or FITNESS FOR A  //
// PARTICULAR PURPOSE. See the GNU General Public        //
// License for more details.                             //
//                                                       //
// You should have received a copy of the GNU General    //
// Public License along with this program; if not,       //
// write to the Free Software Foundation, Inc.,          //
// 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, //
// USA.                                                  //
//                                                       //
//-------------------------------------------------------//
//                                                       //
//    e-mail:     oconrad@saga-gis.org                   //
//                                                       //
//    contact:    Olaf Conrad                            //
//                Institute of Geography                 //
//                University of Hamburg                  //
//                Germany                                //
//                                                       //
///////////////////////////////////////////////////////////

//---------------------------------------------------------


///////////////////////////////////////////////////////////
//                                                       //												
//                                                       //												
//                                                       //
///////////////////////////////////////////////////////////

//---------------------------------------------------------
#ifndef HEADER_INCLUDED__polygon_shared_edges_H
#define HEADER_INCLUDED__polygon_shared_edges_H


///////////////////////////////////////////////////////////
//                                                       //												
//                                                       //												
//                                                       //
///////////////////////////////////////////////////////////

//---------------------------------------------------------
#include "MLB_Interface.h"


///////////////////////////////////////////////////////////
//                                                       //												
//                                                       //												
//                                                       //
///////////////////////////////////////////////////////////

//---------------------------------------------------------
class CPolygon_Shared_Edges : public CSG_Module
{
public: ////// public members and functions: //////////////

	CPolygon_Shared_Edges(void);

//	virtual CSG_String	Get_MenuPath			(void)	{	return( _TL("R:Landsat") );	}


protected: /// protected members and functions: ///////////

	virtual bool		On_Execute				(void);


private: ///// private members and functions: /////////////

	bool				m_bDouble;

	int					m_Field;

	CSG_Shapes			*m_pEdges, *m_pNodes;


	bool				Get_Shared_Edges		(CSG_Shape_Part *pA, CSG_Shape_Part *pB, double Epsilon);

	int					Get_Next_Vertex			(CSG_Shape_Part *pPoints, int iPoint, bool bAscending);

	int					Check_Vertices			(CSG_Shape_Part *pPolygon, CSG_Shape_Part *pVertices, double Epsilon);

};


///////////////////////////////////////////////////////////
//                                                       //
///////////////////////////////////////////////////////////

//---------------------------------------------------------
class CPolygon_Vertex_Check : public CSG_Module
{
public: ////// public members and functions: //////////////

	CPolygon_Vertex_Check(void);

//	virtual CSG_String	Get_MenuPath			(void)	{	return( _TL("R:Landsat") );	}


protected: /// protected members and functions: ///////////

	virtual bool		On_Execute				(void);


private: ///// private members and functions: /////////////

	CSG_Shapes			*m_pAdded;


	bool				Check_Vertices			(CSG_Shape_Part *pPolygon, CSG_Shape_Part *pVertices, double Epsilon);

};


///////////////////////////////////////////////////////////
//                                                       //												
//                                                       //												
//                                                       //
///////////////////////////////////////////////////////////

//---------------------------------------------------------
#endif // #ifndef HEADER_INCLUDED__polygon_shared_edges_H

==> saga_2.3.1+dfsg.orig.tar.gz: saga-2.3.1/src/modules/shapes/shapes_polygons/polygon_shared_edges.h <==
/**********************************************************
 * Version $Id: polygon_shared_edges.h 911 2011-02-14 16:38:15Z reklov_w $
 *********************************************************/

///////////////////////////////////////////////////////////
//                                                       //
//                         SAGA                          //
//                                                       //
//      System for Automated Geoscientific Analyses      //
//                                                       //
//                    Module Library:                    //
//                    shapes_polygons                    //
//                                                       //
//-------------------------------------------------------//
//                                                       //
//                 polygon_shared_edges.h                //
//                                                       //
//                 Copyright (C) 2014 by                 //
//                      Olaf Conrad                      //
//                                                       //
//-------------------------------------------------------//
//                                                       //
// This file is part of 'SAGA - System for Automated     //
// Geoscientific Analyses'. SAGA is free software; you   //
// can redistribute it and/or modify it under the terms  //
// of the GNU General Public License as published by the //
// Free Software Foundation; version 2 of the License.   //
//                                                       //
// SAGA is distributed in the hope that it will be       //
// useful, but WITHOUT ANY WARRANTY; without even the    //
// implied warranty of MERCHANTABILITY or FITNESS FOR A  //
// PARTICULAR PURPOSE. See the GNU General Public        //
// License for more details.                             //
//                                                       //
// You should have received a copy of the GNU General    //
// Public License along with this program; if not,       //
// write to the Free Software Foundation, Inc.,          //
// 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, //
// USA.                                                  //
//                                                       //
//-------------------------------------------------------//
//                                                       //
//    e-mail:     oconrad@saga-gis.org                   //
//                                                       //
//    contact:    Olaf Conrad                            //
//                Institute of Geography                 //
//                University of Hamburg                  //
//                Germany                                //
//                                                       //
///////////////////////////////////////////////////////////

//---------------------------------------------------------


///////////////////////////////////////////////////////////
//                                                       //												
//                                                       //												
//                                                       //
///////////////////////////////////////////////////////////

//---------------------------------------------------------
#ifndef HEADER_INCLUDED__polygon_shared_edges_H
#define HEADER_INCLUDED__polygon_shared_edges_H


///////////////////////////////////////////////////////////
//                                                       //												
//                                                       //												
//                                                       //
///////////////////////////////////////////////////////////

//---------------------------------------------------------
#include "MLB_Interface.h"


///////////////////////////////////////////////////////////
//                                                       //												
//                                                       //												
//                                                       //
///////////////////////////////////////////////////////////

//---------------------------------------------------------
class CPolygon_Shared_Edges : public CSG_Module
{
public: ////// public members and functions: //////////////

	CPolygon_Shared_Edges(void);

//	virtual CSG_String	Get_MenuPath			(void)	{	return( _TL("Landsat") );	}


protected: /// protected members and functions: ///////////

	virtual bool		On_Execute				(void);


private: ///// private members and functions: /////////////

	bool				m_bDouble;

	int					m_Field;

	CSG_Shapes			*m_pEdges, *m_pNodes;


	bool				Get_Shared_Edges		(CSG_Shape_Part *pA, CSG_Shape_Part *pB, double Epsilon);

	int					Get_Next_Vertex			(CSG_Shape_Part *pPoints, int iPoint, bool bAscending);

	int					Check_Vertices			(CSG_Shape_Part *pPolygon, CSG_Shape_Part *pVertices, double Epsilon);

};


///////////////////////////////////////////////////////////
//                                                       //
///////////////////////////////////////////////////////////

//---------------------------------------------------------
class CPolygon_Vertex_Check : public CSG_Module
{
public: ////// public members and functions: //////////////

	CPolygon_Vertex_Check(void);

//	virtual CSG_String	Get_MenuPath			(void)	{	return( _TL("Landsat") );	}


protected: /// protected members and functions: ///////////

	virtual bool		On_Execute				(void);


private: ///// private members and functions: /////////////

	CSG_Shapes			*m_pAdded;


	bool				Check_Vertices			(CSG_Shape_Part *pPolygon, CSG_Shape_Part *pVertices, double Epsilon);

};


///////////////////////////////////////////////////////////
//                                                       //												
//                                                       //												
//                                                       //
///////////////////////////////////////////////////////////

//---------------------------------------------------------
#endif // #ifndef HEADER_INCLUDED__polygon_shared_edges_H
